@@ -1,11 +1,11 @@
 /*
-* Copyright (c) 2021-2023 Golubchikov Mihail <https://github.com/rue-ryuzaki>
-*/
+ * Copyright (c) 2021-2024 Golubchikov Mihail <https://github.com/rue-ryuzaki>
+ */
 
 #include <map>
 
-#include <argparse/argparse_decl.hpp>
-#include "./catch-define.h"
+#define ARGPARSE_DECLARATION
+#include "./argparse_test.hpp"
 
 TEST_CASE("1. to string", "[namespace]")
 {
@@ -24,7 +24,7 @@ TEST_CASE("1. to string", "[namespace]")
         REQUIRE(parser.parse_known_args("--bar a").to_string() == "(Namespace(foo=None, foobar='a'), [])");
 
         argparse::ArgumentParser parser2 = argparse::ArgumentParser().exit_on_error(false);
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         parser2.set_defaults({ { "foo", "bar" } });
 #else
         std::vector<std::pair<std::string, std::string> > values;
@@ -715,7 +715,7 @@ TEST_CASE("2. exists check", "[namespace]")
         REQUIRE(args0.get<std::string>("foo") == "");
         REQUIRE(args0.get<std::string>("bar") == "");
 
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         parser.set_defaults({ { "foo", new_default } });
 #else
         std::vector<std::pair<std::string, std::string> > values;
@@ -797,14 +797,14 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args0.get<std::string>("bar") == "");
         REQUIRE(args0.get<std::vector<std::string> >("foo").size() == 0);
         REQUIRE(args0.get<std::vector<std::string> >("bar").size() == 0);
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         REQUIRE(args0.get<std::map<std::string, std::string> >("foo").size() == 0);
         REQUIRE(args0.get<std::map<std::string, std::string> >("bar").size() == 0);
 #endif  // C++11+
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args0.try_get<std::string>("foo").operator bool() == false);
         REQUIRE(args0.try_get<std::string>("bar").operator bool() == false);
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // delimiter ':'
         argparse::Namespace args1 = parser.parse_args(_make_vec("--foo=key:value"));
@@ -814,12 +814,12 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args1.get<std::string>("bar") == "");
         REQUIRE(args1.get<std::vector<std::string> >("foo").size() == 1);
         REQUIRE(args1.get<std::vector<std::string> >("bar").size() == 0);
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         REQUIRE(args1.get<std::map<std::string, std::string> >("foo", ':').size() == 1);
         REQUIRE(args1.get<std::map<std::string, std::string> >("bar", ':').size() == 0);
         REQUIRE(args1.get<std::map<std::string, std::string> >("foo", ':').at("key") == "value");
 #endif  // C++11+
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args1.try_get<std::string>("foo").operator bool() == true);
         REQUIRE(args1.try_get<std::string>("bar").operator bool() == false);
         REQUIRE(args1.try_get<std::string>("foo").value() == "key:value");
@@ -827,7 +827,7 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args1.try_get<std::vector<std::string> >("bar")->size() == 0);
         REQUIRE(args1.try_get<std::map<std::string, std::string> >("foo", ':')->size() == 1);
         REQUIRE(args1.try_get<std::map<std::string, std::string> >("foo", ':')->at("key") == "value");
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // delimiter '=', std::unordered_map
         argparse::Namespace args2
@@ -838,14 +838,14 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE_THROWS(args2.get<std::string>("bar"));
         REQUIRE(args2.get<std::vector<std::string> >("foo").size() == 1);
         REQUIRE(args2.get<std::vector<std::string> >("bar").size() == 2);
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         REQUIRE(args2.get<std::unordered_map<std::string, std::string> >("foo").size() == 1);
         REQUIRE(args2.get<std::unordered_map<std::string, std::string> >("bar").size() == 2);
         REQUIRE(args2.get<std::unordered_map<std::string, std::string> >("foo").at("key") == "value");
         REQUIRE(args2.get<std::unordered_map<std::string, std::string> >("bar").at("key1") == "value1");
         REQUIRE(args2.get<std::unordered_map<std::string, std::string> >("bar").at("key2") == "value2");
 #endif  // C++11+
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args2.try_get<std::string>("foo").operator bool() == true);
         REQUIRE(args2.try_get<std::string>("bar").operator bool() == false);
         REQUIRE(args2.try_get<std::string>("foo").value() == "key=value");
@@ -856,7 +856,7 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args2.try_get<std::unordered_map<std::string, std::string> >("foo")->at("key") == "value");
         REQUIRE(args2.try_get<std::unordered_map<std::string, std::string> >("bar")->at("key1") == "value1");
         REQUIRE(args2.try_get<std::unordered_map<std::string, std::string> >("bar")->at("key2") == "value2");
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // delimiter '=', std::multimap
         argparse::Namespace args3
@@ -869,13 +869,13 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args3.get<std::vector<std::string> >("bar").size() == 2);
         REQUIRE((args3.get<std::map<std::string, std::string> >("bar").size() == 1));
         REQUIRE((args3.get<std::map<std::string, std::string> >("bar").count("key") == 1));
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
         REQUIRE(args3.get<std::multimap<std::string, std::string> >("foo").size() == 1);
         REQUIRE(args3.get<std::multimap<std::string, std::string> >("bar").size() == 2);
         REQUIRE(args3.get<std::multimap<std::string, std::string> >("foo").count("key") == 1);
         REQUIRE(args3.get<std::multimap<std::string, std::string> >("bar").count("key") == 2);
 #endif  // C++11+
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args3.try_get<std::string>("foo").operator bool() == true);
         REQUIRE(args3.try_get<std::string>("bar").operator bool() == false);
         REQUIRE(args3.try_get<std::string>("foo").value() == "key=value");
@@ -887,7 +887,7 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args3.try_get<std::multimap<std::string, std::string> >("bar")->size() == 2);
         REQUIRE(args3.try_get<std::multimap<std::string, std::string> >("foo")->count("key") == 1);
         REQUIRE(args3.try_get<std::multimap<std::string, std::string> >("bar")->count("key") == 2);
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
     }
 
     SECTION("4.2. paired types") {
@@ -899,9 +899,9 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args0.exists("foo") == false);
         REQUIRE(args0.get<std::string>("foo") == "");
         REQUIRE(args0.get<std::vector<std::string> >("foo").size() == 0);
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args0.try_get<std::string>("foo").operator bool() == false);
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // delimiter ':'
         argparse::Namespace args1 = parser.parse_args(_make_vec("--foo=key:value"));
@@ -910,13 +910,13 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args1.get<std::vector<std::string> >("foo").size() == 1);
         REQUIRE((args1.get<std::pair<std::string, std::string> >("foo", ':').first == "key"));
         REQUIRE((args1.get<std::pair<std::string, std::string> >("foo", ':').second == "value"));
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args1.try_get<std::string>("foo").operator bool() == true);
         REQUIRE(args1.try_get<std::string>("foo").value() == "key:value");
         REQUIRE(args1.try_get<std::vector<std::string> >("foo")->size() == 1);
         REQUIRE(args1.try_get<std::pair<std::string, std::string> >("foo", ':')->first == "key");
         REQUIRE(args1.try_get<std::pair<std::string, std::string> >("foo", ':')->second == "value");
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // empty values
         std::pair<std::string, std::string> pair_first
@@ -939,14 +939,14 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(args2.get<std::vector<std::string> >("foo").size() == 2);
         REQUIRE((args2.get<std::pair<std::string, std::string> >("foo", ' ').first == "key"));
         REQUIRE((args2.get<std::pair<std::string, std::string> >("foo", ' ').second == "value"));
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args2.try_get<std::vector<std::string> >("foo")->size() == 2);
         REQUIRE(args2.try_get<std::pair<std::string, std::string> >("foo", ' ')->first == "key");
         REQUIRE(args2.try_get<std::pair<std::string, std::string> >("foo", ' ')->second == "value");
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
     }
 
-#ifdef _ARGPARSE_CXX_11
+#ifdef ARGPARSE_CXX_11
     SECTION("4.3. tuple") {
         argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
 
@@ -966,7 +966,7 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(std::get<0>(tuple1) == 1);
         REQUIRE(std::get<1>(tuple1) == "value");
         REQUIRE(std::get<2>(tuple1) == 3);
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args1.try_get<std::string>("foo").operator bool() == true);
         REQUIRE(args1.try_get<std::string>("foo").value() == "1:value:3");
         REQUIRE(args1.try_get<std::vector<std::string> >("foo")->size() == 1);
@@ -974,7 +974,7 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(std::get<0>(try_tuple1.value()) == 1);
         REQUIRE(std::get<1>(try_tuple1.value()) == "value");
         REQUIRE(std::get<2>(try_tuple1.value()) == 3);
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
 
         // empty values
         auto tuple1beg = parser.parse_args("--foo=:value:3")
@@ -1006,13 +1006,13 @@ TEST_CASE("4. value types check", "[namespace]")
         REQUIRE(std::get<0>(tuple2) == 1);
         REQUIRE(std::get<1>(tuple2) == "value");
         REQUIRE(std::get<2>(tuple2) == 3);
-#ifdef _ARGPARSE_CXX_17
+#ifdef ARGPARSE_HAS_OPTIONAL
         REQUIRE(args2.try_get<std::vector<std::string> >("foo")->size() == 3);
         auto try_tuple2 = args2.try_get<std::tuple<int, std::string, int> >("foo", ' ');
         REQUIRE(std::get<0>(try_tuple2.value()) == 1);
         REQUIRE(std::get<1>(try_tuple2.value()) == "value");
         REQUIRE(std::get<2>(try_tuple2.value()) == 3);
-#endif  // C++17+
+#endif  // ARGPARSE_HAS_OPTIONAL
     }
 #endif  // C++11+
 }
